@@ -4,13 +4,13 @@
  *
  * This file contains protocol support for spanning-tree inspircd, b6 or later.
  *
- * $Id: inspircd.c 4805 2006-02-09 20:33:19Z nenolod $
+ * $Id: inspircd.c 5131 2006-04-29 19:09:24Z jilles $
  */
 
 #include "atheme.h"
 #include "protocol/inspircd.h"
 
-DECLARE_MODULE_V1("protocol/inspircd", TRUE, _modinit, NULL, "$Id: inspircd.c 4805 2006-02-09 20:33:19Z nenolod $", "InspIRCd Core Team <http://www.inspircd.org/>");
+DECLARE_MODULE_V1("protocol/inspircd", TRUE, _modinit, NULL, "$Id: inspircd.c 5131 2006-04-29 19:09:24Z jilles $", "InspIRCd Core Team <http://www.inspircd.org/>");
 
 /* *INDENT-OFF* */
 
@@ -131,15 +131,44 @@ static void inspircd_wallops(char *fmt, ...)
 {
 	va_list ap;
 	char buf[BUFSIZE];
+	char *sendernick;
+	user_t *u;
+	node_t *n;
 
 	if (config_options.silent)
 		return;
 
+	if (me.me == NULL)
+	{
+		/*
+		 * this means we have no pseudoclients -- under present inspircd, servers cannot globops, and
+		 * thus, we will need to bail -- slog, and let them know. --w00t
+		 *
+		 * XXX - we shouldn't rely on me.me being NULL, me.me->userlist or something instead. --w00t
+		 */
+		 slog(LG_ERROR, "wallops(): InspIRCD requires at least one pseudoclient module to be loaded to send wallops.");
+	}
+
 	va_start(ap, fmt);
 	vsnprintf(buf, BUFSIZE, fmt, ap);
 	va_end(ap);
 
-	sts(":%s GLOBOPS :%s", me.name, buf);
+	if (is_internal_client(user_find_named(opersvs.nick)))
+	{
+		sendernick = opersvs.nick;
+	}
+	else
+	{
+		LIST_FOREACH(n, me.me->userlist.head)
+		{
+			u = (user_t *)n->data;
+
+			sendernick = u->nick;
+			break;
+		}
+	}
+
+	sts(":%s GLOBOPS :%s", sendernick, buf);
 }
 
 /* join a channel */
@@ -209,7 +238,7 @@ static void inspircd_numeric_sts(char *from, int numeric, char *target, char *fm
 	vsnprintf(buf, BUFSIZE, fmt, ap);
 	va_end(ap);
 
-	/* InspIRCd doesnt pass numerics around */
+	sts(":%s PUSH %s ::%s %d %s %s", me.name, target, from, numeric, target, buf);
 }
 
 /* KILL wrapper */
@@ -457,7 +486,6 @@ static void m_nick(char *origin, uint8_t parc, char *parv[])
 {
 	server_t *s;
 	user_t *u;
-	kline_t *k;
 
 	/* :services-dev.chatspike.net NICK 1133994664 DevNull chatspike.net chatspike.net services +i 0.0.0.0 :/dev/null -- message sink */
 	if (parc == 8)
@@ -471,21 +499,6 @@ static void m_nick(char *origin, uint8_t parc, char *parv[])
 
 		slog(LG_DEBUG, "m_nick(): new user on `%s': %s", s->name, parv[1]);
 
-		if ((k = kline_find(parv[4], parv[2])))
-		{
-			/* the new user matches a kline.
-			 * the server introducing the user probably wasn't around when
-			 * we added the kline or isn't accepting klines from us.
-			 * either way, we'll KILL the user and send the server
-			 * a new KLINE.
-			 */
-
-			skill(opersvs.nick, parv[1], k->reason);
-			kline_sts(origin, k->user, k->host, (k->expires - CURRTIME), k->reason);
-
-			return;
-		}
-
 		/* char *nick, char *user, char *host, char *vhost, char *ip, char *uid, char *gecos, server_t *server, uint32_t ts */
 		u = user_add(parv[1], parv[4], parv[2], parv[3], parv[6], NULL, parv[7], s, atol(parv[0]));
 
