@@ -4,13 +4,13 @@
  *
  * This file contains protocol support for Ultimate3 ircd.
  *
- * $Id: ultimate3.c 4721 2006-01-25 12:43:15Z jilles $
+ * $Id: ultimate3.c 5131 2006-04-29 19:09:24Z jilles $
  */
 
 #include "atheme.h"
 #include "protocol/ultimate3.h"
 
-DECLARE_MODULE_V1("protocol/ultimate3", TRUE, _modinit, NULL, "$Id: ultimate3.c 4721 2006-01-25 12:43:15Z jilles $", "Atheme Development Group <http://www.atheme.org>");
+DECLARE_MODULE_V1("protocol/ultimate3", TRUE, _modinit, NULL, "$Id: ultimate3.c 5131 2006-04-29 19:09:24Z jilles $", "Atheme Development Group <http://www.atheme.org>");
 
 /* *INDENT-OFF* */
 
@@ -96,7 +96,7 @@ static uint8_t ultimate3_server_login(void)
 /* introduce a client */
 static void ultimate3_introduce_nick(char *nick, char *user, char *host, char *real, char *uid)
 {
-	sts("CLIENT %s 1 %ld %s + %s %s * %s 0 0 :%s", nick, CURRTIME, "io", user, host, me.name, real);
+	sts("CLIENT %s 1 %ld +%sS + %s %s * %s 0 0 :%s", nick, CURRTIME, "io", user, host, me.name, real);
 }
 
 /* invite a user to a channel */
@@ -529,7 +529,6 @@ static void m_nick(char *origin, uint8_t parc, char *parv[])
 {
 	server_t *s;
 	user_t *u;
-	kline_t *k;
 	char *ipbuf;
 	struct in_addr addr;
 
@@ -544,22 +543,6 @@ static void m_nick(char *origin, uint8_t parc, char *parv[])
 
 		slog(LG_DEBUG, "m_nick(): new user on `%s': %s", s->name, parv[0]);
 
-		if ((k = kline_find(parv[5], parv[6])))
-		{
-			/*
-			 * the new user matches a kline.
-			 * * the server introducing the user probably wasn't around when
-			 * * we added the kline or isn't accepting klines from us.
-			 * * either way, we'll KILL the user and send the server
-			 * * a new KLINE.
-			 */
-
-			skill(opersvs.nick, parv[0], k->reason);
-			kline_sts(parv[6], k->user, k->host, (k->expires - CURRTIME), k->reason);
-
-			return;
-		}
-
 		addr.s_addr = htonl(strtoul(parv[10], NULL, 0));
 #ifndef _WIN32
 		ipbuf = inet_ntoa(addr);
